<?php

namespace FM\Service;

use FM\Factory\Fm00004000TarefasFactory;
use Teknisa\Libs\Util\Environment;
use Teknisa\Libs\Util\NewCode;
use Doctrine\ORM\EntityManager;
use FM\Service\FuncionariosHierarqService;
use FM\Service\FindService;

class Fm00004000TarefasService
{

    protected $TarefasFactory;
    protected $Environment;
    protected $newCode;
    protected $FuncionariosHierarqService;
    protected $FindService;

    public function __construct(EntityManager $entityManager, Fm00004000TarefasFactory $TarefasFactory, FuncionariosHierarqService $FuncionariosHierarqService, FindService $FindService, Environment $Environment, NewCode $newCode) {
        $this->connection                   = $entityManager->getConnection();
        $this->TarefasFactory               = $TarefasFactory;
        $this->FuncionariosHierarqService   = $FuncionariosHierarqService;
        $this->FindService                  = $FindService;
        $this->Environment                  = $Environment;
        $this->newCode                      = $newCode;
    }

    // integração SM
    public function getContratos($parametros) {

        $retorno = $this->FindService->formatarArray($parametros['NRESTRUTURAM']);
        return $this->TarefasFactory->getContratos($retorno);
    }

    public function getTarefasGrid()
    {
        $cdoperador = $this->Environment->getCdOperador();
        $listaOperadores = $this->FuncionariosHierarqService->montarHierarquiaOperadores($cdoperador);

        $params = array(
            "CDOPERADOR" => $cdoperador
        );
       
        return $this->TarefasFactory->getTarefasGrid($params, $listaOperadores);
    }

    public function getClientes()
    {
        return $this->TarefasFactory->getClientes();
    }

    public function getTipoLocal()
    {
        return $this->TarefasFactory->getTipoLocal();
    }

    public function getLocal($parametros)
    {
        
        $param = implode(',', $parametros['NRTIPOLOCALCLI']);
        return $this->TarefasFactory->getLocal($param);
    }

    public function getChecklistTarefa($parametros)
    {
        $param = implode(',', $parametros['NRTIPOLOCALCLI']);
        return $this->TarefasFactory->getChecklistTarefa($param);
    }

    public function getItensChecklist($parametros)
    {
        return $this->TarefasFactory->getItensChecklist($parametros);
    }

    public function getEscopo()
    {
        return $this->TarefasFactory->getEscopo();
    }

    public function getTarefasSelect($parametros)
    {
        $param = implode(',', $parametros['NRATIVIDADECHK']);
        return $this->TarefasFactory->getTarefasSelect($param);
    }

    public function getCriterioTarefa()
    {
        return $this->TarefasFactory->getCriterioTarefa();
    }

    public function getCriterios($parametros)
    {
        $param = array(
            "NRTAREFACHK"    => implode(',', $parametros['NRTAREFACHK']),
            "NRATIVIDADECHK" => implode(',', $parametros['NRATIVIDADECHK']),
            "NRCHECKLIST"    => $parametros['NRCHECKLIST']
        );
        return $this->TarefasFactory->getCriterios($param);
    }

    public function getFuncionario()
    {
        return $this->TarefasFactory->getFuncionario();
    }

    public function getSupervisorTarefa()
    {
        return $this->TarefasFactory->getSupervisorTarefa();
    }

    public function insertNovaTarefa($param)
    {
        $this->connection->beginTransaction();
        try {
           
            $NRORG =  $this->Environment->getNrOrg();

            if ($param['OBSERVACOES'] == 1) {
                $observacoesTarefa = "N";
                $observacoesVistoria = "N";
            } elseif ($param['OBSERVACOES'] == 2) {
                $observacoesTarefa = "S";
                $observacoesVistoria = "N";
            } elseif ($param['OBSERVACOES'] == 3) {
                $observacoesTarefa = "N";
                $observacoesVistoria = "S";
            } else {
                $observacoesTarefa = "S";
                $observacoesVistoria = "S";
            }
           
            foreach ($param['NRSEQCONTRATO'] as $contrato) {
                foreach ($param["EXECUTORHORA"] as $row) {
                   $validador =  isset($row["IGNORAR"]) ? $row["IGNORAR"] : "0";
                    if($validador != '1'){
                        foreach ($param['NRLOCALCLIENTE'] as $local) {
                           
                            $nrchecklistagend = $this->newCode->getCodeByTableName("FCM_CHECKLISTAGEND", $NRORG, 1, 10, true);
                            $params = array(
                                "NRCHECKLISTAGEND"      => $nrchecklistagend,
                                "NMCHECKLISTAGEND"      => $param['NOMETAREFA'],
                                "NRLOCALCLIENTE"        => $local,
                                "NRCHECKLIST"           => $param['NRCHECKLIST'],
                                "CDOPERADOR"            => $row['FUNCIONARIO'],
                                "IDSITUACAOAGEND"       => 1,
                                "DTHORAAGEND"           => $row['DATAINICIAL'],
                                "DTHRFINALAGEND"        => $row['DATAFINAL'],
                                "CDOPERINCLUSAO"        => $this->Environment->getCdOperador(),
                                "IDOBRIGAOBSERVACAO"    => $observacoesTarefa,
                                "NRSEQCONTRATO"         => $contrato,
                            );
                        
                            $this->TarefasFactory->insertChecklist($params);
                        
                            foreach ($param['NRTAREFACHK'] as $atividade) {
                                $nrtarefaagend = $this->newCode->getCodeByTableName("FCM_TAREFAAGEND", $NRORG, 1, 10, true);
                                $params = array(
                                    "NRTAREFAAGEND" => $nrtarefaagend,
                                    "NRCHECKLISTAGEND" => $nrchecklistagend,
                                    "NRTAREFACHK" => $atividade,
                                    "CDOPERADOR" => $row['FUNCIONARIO'],
                                    "DTHORAAGEND" => $row['DATAINICIAL'],
                                    "DSOBSTAREFAAGEND" => null,
                                    "CDOPERINCLUSAO" => $this->Environment->getCdOperador(),
                                    "NRTAREFARECORRENTE" =>  isset($param["NRTAREFARECORRENTE"]) ? $param["NRTAREFARECORRENTE"] : null,
                                );
                                
                                $this->TarefasFactory->insertTarefa($params);
                        
                                foreach ($param['NRCRITERIOTAREFACHK'] as $criterios) {
                        
                                    //valida se  o critério realmente pertence à atividade que está sendo inserida acima.
                                    $paramsValida = array(
                                        "NRTAREFACHK"      => $atividade,
                                        "NRCRITERIOTAREFA" => $criterios['NRCRITERIOTAREFA']
                                    );
                        
                                    $valida = $this->TarefasFactory->validaCriterio($paramsValida);
                        
                                    if ($valida > 0) { 
                        
                                        $nrcriteriostaragend = $this->newCode->getCodeByTableName("FCM_CRITERIOTARAGEND", $NRORG, 1, 10, true);
                                        $params = array(
                                            "NRCRITERIOTARAGEND" => $nrcriteriostaragend,
                                            "NMCRITERIOTARAGEND" => $criterios['DSCRITERIOTAREFA'],
                                            "NRTAREFAAGEND" => $nrtarefaagend,
                                            "NRCRITERIOTAREFACHK" => ($criterios['NRCRITERIOTAREFACHK'] === $criterios['DSCRITERIOTAREFA']) ? null : $criterios['NRCRITERIOTAREFACHK'],
                                            "OPERADOR" => $this->Environment->getCdOperador()
                                        );
                        
                                        $this->TarefasFactory->insertCriterio($params);
                                    }
                                }
                            }
                            if ($param["VISTORIA"] == 1) {
                                $nrgerenciamentochk = $this->newCode->getCodeByTableName("FCM_GERENCIAMENTOCHK", $NRORG, 1, 10, true);
                                $params = array(
                                    "NRGERENCIAMENTOCHK"    => $nrgerenciamentochk,
                                    "NMGERENCIAMENTOCHK"    => $param['NOMETAREFA'],
                                    "NRLOCALCLIENTE"        => $local,
                                    "NRCHECKLIST"           => $param['NRCHECKLIST'],
                                    "CDOPERADOR"            => $row['ENCARREGADO'],
                                    "DTHORAAGEND"           => $row['DATAINICIAL'],
                                    "DTHRFINALAGEND"        => $row['DATAFINAL'],
                                    "OPERADOR"              => $this->Environment->getCdOperador(),
                                    "NRCHECKLISTAGEND"      => $nrchecklistagend,
                                    "IDOBRIGAOBSERVACAO"    => $observacoesVistoria,
                                    "NRSEQCONTRATO"         => $contrato
                                );
                        
                                $this->TarefasFactory->insertChk($params);
                        
                                foreach ($param['NRTAREFACHK'] as $atividade) {
                                    $nrtarefaagendchk = $this->newCode->getCodeByTableName("FCM_TAREFAGERCHK", $NRORG, 1, 10, true);
                                    $params = array(
                                        "NRTAREFAGERCHK" => $nrtarefaagendchk,
                                        "NRGERENCIAMENTOCHK" => $nrgerenciamentochk,
                                        "NRTAREFACHK" => $atividade,
                                        "CDOPERADOR" => $row['FUNCIONARIO'],
                                        "DTHORATAREFAGERCHK" => $row['DATAINICIAL'],
                                        "DSOBSTAREFAGERCHK" => null,
                                        "OPERADOR" => $this->Environment->getCdOperador()
                                    );
                        
                                    $this->TarefasFactory->insertChkTarefa($params);
                        
                                    foreach ($param['NRCRITERIOTAREFACHK'] as $criterios) {
                        
                                        //valida se  o critério realmente pertence à atividade que está sendo inserida acima.
                                        $paramsValida = array(
                                            "NRTAREFACHK"      => $atividade,
                                            "NRCRITERIOTAREFA" => $criterios['NRCRITERIOTAREFA']
                                        );
                        
                                        $valida = $this->TarefasFactory->validaCriterio($paramsValida);
                        
                                        if ($valida > 0) {                                     
                        
                                            $nrcriteriostaragerchk = $this->newCode->getCodeByTableName("FCM_CRITERIOTARGERCHK", $NRORG, 1, 10, true);
                                            $params = array(
                                                "NRCRITERIOTARGERCHK" => $nrcriteriostaragerchk,
                                                "NMCRITERIOTARGERCHK" => $criterios['DSCRITERIOTAREFA'],
                                                "NRTAREFAGERCHK" => $nrtarefaagendchk,
                                                "NRCRITERIOTAREFACHK" => ($criterios['NRCRITERIOTAREFACHK'] === $criterios['DSCRITERIOTAREFA']) ? null : $criterios['NRCRITERIOTAREFACHK'],
                                                "OPERADOR" => $this->Environment->getCdOperador()
                                            );
                        
                                            $this->TarefasFactory->insertChkCriterio($params);
                                        }
                                    }
                                }
                            }
                        }
                    }
               }
            }
   
            $this->connection->commit();
        } catch (\Exception $e) {
            $this->connection->rollback();
            throw $e;
        }
    }

    public function inativarTarefas($parametros)
    {
        $this->connection->beginTransaction();
        try {
            
            $param = implode(',', $parametros["NRS"]);
            
            $this->TarefasFactory->deletarTarefas($param);
            $this->connection->commit();
        } catch (\Exception $e) {
            $this->connection->rollback();
            throw $e;
        }
    }
}
