<?php
namespace Teknisa\Libs\Service;

use Teknisa\Libs\Util\Environment;
use Teknisa\Libs\Util\InstanceProvider;
use Teknisa\Libs\Util\Utilities;

class Metadata
{
    const DS = DIRECTORY_SEPARATOR;
    const JSON_NAME_NOTFOUND = 'notfound';
    const JSON_NAME_UNAUTHORIZED = 'unauthorized';
    /**
     * @var Environment
     */
    private $environment;

    public function __construct(Environment $environment)
    {
        $this->environment = $environment;
    }

    public function findMetadata($jsonPath, $routePath = null)
    {
        $isAdm = InstanceProvider::getSession()->get('ACL_ADMINISTRATOR');
        $isJsonFragment = !$routePath;

        if (Utilities::isModule()) {
            $jsonMetadata = $this->getJsonMetadataByModule($jsonPath);
        } else {
            $jsonMetadata = $this->getJsonMetadataByProduct($jsonPath);
        }

        if (!$jsonMetadata) {
            return $this->getJsonMetadataByProduct(self::JSON_NAME_NOTFOUND);
        }

        if ($isAdm) {
            return $jsonMetadata;
        }

        if (!$isJsonFragment && $this->unauthorizedAccessToJsonMetadata($routePath)) {
            return $this->getJsonMetadataByProduct(self::JSON_NAME_UNAUTHORIZED);
        }

        $notAuthorized = $this->filterMetadataByAcl($jsonMetadata);

        if ($notAuthorized && $isJsonFragment) {
            return [];
        }

        if ($notAuthorized && !$isJsonFragment) {
            return $this->getJsonMetadataByProduct(self::JSON_NAME_UNAUTHORIZED);
        }

        return $jsonMetadata;
    }

    /**
     * @param $metadata
     * @return bool
     */
    private function filterMetadataByAcl(&$metadata): bool
    {
        foreach ($metadata as $key => &$data) {
            if (is_array($data)) {
                $notAuthorized = $this->filterMetadataByAcl($data);
                if ($notAuthorized) {
                    unset($metadata[$key]);
                    $metadata = array_values($metadata);
                }
            } else {
                if ($key === 'aclLabel' && !$this->checkLabelInSession($data)) {
                    return true;
                }
            }
        }
        return false;
    }

    /**
     * @param $label
     * @return bool
     */
    private function checkLabelInSession($label): bool
    {
        $userAclLabels = InstanceProvider::getSession()->get('USER_ACL_LABELS');
        return in_array($label, $userAclLabels);
    }

    /**
     * @param $name
     * @return string
     */
    private function getJsonMetadataPathByProduct($name): string
    {
        return Utilities::getProductBasePath() . self::DS . Utilities::getJsonMetadataPathByProductParameter() . self::DS . $name . '.json';
    }

    /**
     * @param $name
     * @return string
     * Mudar método posteriormente
     */
    private function getJsonMetadataPathByModule($name): string
    {
        return Utilities::getProductBasePath() . self::DS . Utilities::getJsonMetadataPathByModuleParameter() . self::DS . $name . '.json';
    }


    /**
     * @param $jsonPath
     * @return mixed
     */
    private function getJsonMetadataByProduct($jsonPath)
    {
        $jsonMetadataPath = $this->getJsonMetadataPathByProduct($jsonPath);
        return @json_decode(file_get_contents($jsonMetadataPath), true);
    }

    private function getJsonMetadataByModule($jsonPath)
    {
        $jsonMetadataPath = $this->getJsonMetadataPathByModule($jsonPath);
        return @json_decode(file_get_contents($jsonMetadataPath), true);
    }

    /**
     * @param $routePath
     * @return bool
     */
    private function unauthorizedAccessToJsonMetadata($routePath): bool
    {
        $menuRoutes = InstanceProvider::getSession()->get('MENU_ROUTES');
        return isset($menuRoutes[$routePath]) && !$menuRoutes[$routePath];
    }

    /**
     * @param $routePath
     * @return bool
     */
    private function hasIndexInMenuRoutesSession($routePath): bool
    {
        $menuRoutes = InstanceProvider::getSession()->get('MENU_ROUTES');
        return isset($menuRoutes[$routePath]);
    }
}
