/* eslint-disable */
import { Utilities } from '@/util/Utilities';
import {
    CheckboxMultiple, ComponentRender, DateRange, DialogService, Form, LoadingService, Modal, ModalService, Select,
    SelectMultiple, Switch, TextInput, Time,
} from '@zeedhi/common';
import { Http, IEventParam, Loader, Metadata } from '@zeedhi/core';
import { TekGrid, TekTreeGrid, } from '@zeedhi/teknisa-components-common';
import { ModalControllerAddProcedimento } from '../ModalControllerAddProcedimento';

export class Fm00004000TarefasController {
    private cadastroTarefas!: Modal;

    private basicModalCriterio!: Modal;

    private modalConflitoDatas!: Modal;

    public hierarquiasController = Loader.getInstance('HierarquiasController');

    public visivel = true;

    public acessorVisivel = true;

    public operadorEditable: boolean = false;

    public horaInicio: boolean = false;

    public conflitoDatas: any = [];

    public bancoConflito: any = [];

    public title: String = "";

    public visibilidadeGridItens: boolean = false;

    public visibilidadeForm: boolean = true;

    public copy: any;

    public parametrizacao = "";

    // ============Controle do modal==========
    // O modal cadastroTarefas  também é usado na tela "Calendário" pelo botão "Cadastrar Tarefa"
    public async exibirModalCadastroTarefas({ event }: any) {
        event.preventDefault();
        this.cadastroTarefas = await ModalService.createFromJsonPost('', { jsonPath: 'fm_00004_000_tarefas/modal/fm_00004_001_modal_cadastro_tarefas' });
        this.cadastroTarefas.show();
        this.validaParametrizacao();
    }

    public async fecharModalTarefas() {
        this.cadastroTarefas.hide();
        this.cadastroTarefas?.destroy();
    }

    public async exibirModalCriterios() {
        this.basicModalCriterio = await ModalService.createFromJsonPost('', { jsonPath: 'fm_00004_000_tarefas/modal/fm_00004_002_modal_cadastro_criterio' });
        this.basicModalCriterio.show();
    }

    public async fecharModalCriterio() {
        this.basicModalCriterio.hide();
        this.basicModalCriterio?.destroy();
    }

    public clickButtonToExpand({ component }: any) {
        const form = Metadata.getInstance<Form>(`formTarefas_${component.name}`);
        form.isVisible = !form.isVisible;
        component.iconName = (component.iconName === 'mdi-chevron-down') ? 'mdi-chevron-right' : 'mdi-chevron-down';
    }

    public async exibirModalConflitoDatas() {
        if (this.modalConflitoDatas) {
            await this.fecharModalConflitoDatas();
        }
        this.modalConflitoDatas = await ModalService.createFromJsonPost('', { jsonPath: 'fm_00004_000_tarefas/modal/fm_00004_004_modal_conflito_datas' });
        this.modalConflitoDatas.show();
    }

    public async fecharModalConflitoDatas() {
        this.modalConflitoDatas.hide();
        this.modalConflitoDatas?.destroy();
        this.visibilidadeGridItens = false;
        this.visibilidadeForm = true;
    }

    // ==========Controles dos Selects ===================

    // INTEGRAÇÃO COM SM
    public changeContratos({ component }: any) {
        const selectContratos = Metadata.getInstance<SelectMultiple>('NRSEQCONTRATO');
        if (component.value.length > 0) {
            selectContratos.disabled = false;
            const { selectValue } = component;

            selectContratos.datasource.setFilter({
                NRESTRUTURAM: selectValue.map((item: any) => item.NRESTRUTURAM),
            });
        } else if (component.value.length < 1) {
            selectContratos.disabled = true;
        }
    }

    public changeTipoDeLocal() {
        const cliente = Metadata.getInstance<Select>('CDCLIENTE');
        const tipoLocal = Metadata.getInstance<Select>('NRTIPOLOCALCLI');
        if (cliente.value) {
            tipoLocal.disabled = false;
        } else {
            tipoLocal.disabled = true;
        }
    }

    public changeLocal() {
        const tipoLocal = Metadata.getInstance<Select>('NRTIPOLOCALCLI');
        const local = Metadata.getInstance<SelectMultiple>('NRLOCALCLIENTE');
        const checklist = Metadata.getInstance<Select>('NRCHECKLIST');
        if (tipoLocal.value.length > 0) {
            local.disabled = false;
            checklist.disabled = false;
            local.datasource.setFilter({
                NRTIPOLOCALCLI: tipoLocal.value,
            });
            checklist.datasource.setFilter({
                NRTIPOLOCALCLI: tipoLocal.value,
            });
        } else {
            local.setValue([]);
            local.disabled = true;
            checklist.setValue(null);
            checklist.disabled = true;
        }
    }

    public changeItensChecklist() {
        const checklist = Metadata.getInstance<Select>('NRCHECKLIST');
        const itenschecklist = Metadata.getInstance<SelectMultiple>('NRATIVIDADECHK');
        if (checklist.value) {
            itenschecklist.disabled = false;
            itenschecklist.datasource.setFilter({
                NRCHECKLIST: checklist.value,
            });
        } else {
            itenschecklist.setValue([]);
            itenschecklist.disabled = true;
        }
    }

    public changeEscopo() {
        const itenschecklist = Metadata.getInstance<SelectMultiple>('NRTIPOLOCALCLI');
        const escopo = Metadata.getInstance<Select>('NRESCOPOSTAREFA');
        if (itenschecklist.value.length > 0) {
            escopo.disabled = false;
        } else {
            escopo.setValue([]);
            escopo.disabled = true;
        }
    }

    public changeTarefa() {
        const escopo = Metadata.getInstance<SelectMultiple>('NRESCOPOSTAREFA');
        const tarefa = Metadata.getInstance<SelectMultiple>('NRTAREFACHK');
        const itenschecklist = Metadata.getInstance<Select>('NRATIVIDADECHK');
        if (escopo.value.length > 0) {
            tarefa.disabled = false;
            tarefa.datasource.setFilter({
                NRATIVIDADECHK: itenschecklist.value,
            });
        } else {
            tarefa.setValue([]);
            tarefa.disabled = true;
        }
    }

    public setCriterios() {
        const tarefa = Metadata.getInstance<SelectMultiple>('NRTAREFACHK');
        const itenschecklist = Metadata.getInstance<Select>('NRATIVIDADECHK');
        const checklist = Metadata.getInstance<Select>('NRCHECKLIST');
        const checkbox = Metadata.getInstance<CheckboxMultiple>('NRCRITERIOTAREFACHK');
        if (tarefa.value.length > 0) {
            checkbox.datasource?.setFilter({
                NRTAREFACHK: tarefa.value,
                NRATIVIDADECHK: itenschecklist.value,
                NRCHECKLIST: checklist.value,
            });
            checkbox.datasource?.get();
            checkbox.isVisible = true;
        } else {
            tarefa.setValue([]);
            checkbox.isVisible = false;
        }
    }

    public novoCriterio() {
        const chk = Metadata.getInstance<CheckboxMultiple>('NRCRITERIOTAREFACHK');
        const valor = Metadata.getInstance<TextInput>('inputNovoCriterio').value;
        chk!.datasource!.data!.push({
            NRCRITERIOTAREFACHK: valor,
            DSCRITERIOTAREFA: valor,
        });
        chk!.value.push(valor);
        this.fecharModalCriterio();
    }

    public setFiltro({ component }: any) {
        component.datasource.dynamicFilter = {
            IDATIVO: [{
                relation: 'AND',
                operation: 'IN',
                value: 'S',
            }],
        };
        component.datasource.get();
    }

    public validaVistoria() {
        const vistoria = Metadata.getInstance<Select>('selectCriarVistoria');
        const observacao = Metadata.getInstance<Select>('selectObservacoesObrigatorias');
        if (vistoria.value == 1) {
            observacao!.datasource!.data!.push({
                value: '3',
                text: "Somente na vistoria",
            });
            observacao!.datasource!.data!.push({
                value: '4',
                text: "Na tarefa e na vistoria",
            });
        } else {
            observacao.datasource?.get();
        }
    }

    /* ================ Funções responsáveis para fazer a inserção das tarefas ===================================== */

    public validaDiaPeriodo(data: any, data2: any, dias: any) {
        for (let dataAux = data; data <= data2; dataAux.setDate(dataAux.getDate() + 1)) {
            if (dias.includes(String(dataAux.getDay()))) {
                return true;
            }
        }
        return false;
    }

    public validaInsercao() {
        const formTarefas = Metadata.getInstance<Form>('formCadastroTarefas').validate();
        const formCriterios = Metadata.getInstance<Form>('formTarefas_dropBoxCriterioAvaliacao').validate();
        const formAgendamento = Metadata.getInstance<Form>('formTarefas_dropBoxDadosAgendamento').validate();
        return (formTarefas && formCriterios && formAgendamento);
    }

    public executorHora() {
        const form = Metadata.getInstance<Form>('formTarefas_dropBoxDadosAgendamento');
        const switchValues = Metadata.getInstance<Switch>('switchFunionario');
        let dados = [];
        for (let pos = 4; pos < (form.children.length - 1); pos += 1) {
            let codigoPos: any = form.children[pos];
            codigoPos = codigoPos.children[1].name.substr(16);
            dados.push({
                HORAINICIO: Metadata.getInstance<Time>('selectHoraInicio' + String(codigoPos)).value,
                DURACAO: Metadata.getInstance<TextInput>('selectdDuracao' + String(codigoPos)).value,
                FUNCIONARIO: Metadata.getInstance<Select>('selectFuncionario' + String(switchValues.value ? 1 : codigoPos)).value,
                ENCARREGADO: Metadata.getInstance<Select>('selectEncarregado' + String(switchValues.value ? 1 : codigoPos)).value,
            });
        }
        return dados;
    }

    public inserirTarefa() {
        const grid = Metadata.getInstance<TekGrid>('tek-grid-tarefas');
        const checkBoxMultiple = Metadata.getInstance<CheckboxMultiple>('NRCRITERIOTAREFACHK');
        const diaSemana = Metadata.getInstance<SelectMultiple>('selectDiaSemana').value;
        const dataRange = Metadata.getInstance<DateRange>('selectDataDe').value;
        if (this.validaDiaPeriodo(new Date(dataRange[0]), new Date(dataRange[1]), diaSemana)) {
            const dados = (this.bancoConflito.length > 0) ? this.bancoConflito : this.executorHora();
            LoadingService.show();
            Http.post('/insertNovaTarefa', {
                NOMETAREFA: Metadata.getInstance<TextInput>('nomeTarefa').value,
                CDCLIENTE: Metadata.getInstance<Select>('CDCLIENTE').value,
                NRTIPOLOCALCLI: Metadata.getInstance<SelectMultiple>('NRTIPOLOCALCLI').value,
                NRLOCALCLIENTE: Metadata.getInstance<SelectMultiple>('NRLOCALCLIENTE').value,
                NRCHECKLIST: Metadata.getInstance<Select>('NRCHECKLIST').value,
                NRATIVIDADECHK: Metadata.getInstance<SelectMultiple>('NRATIVIDADECHK').value,
                NRESCOPOSTAREFA: Metadata.getInstance<SelectMultiple>('NRESCOPOSTAREFA').value,
                NRTAREFACHK: Metadata.getInstance<SelectMultiple>('NRTAREFACHK').value,
                NRCRITERIOTAREFACHK: checkBoxMultiple.datasource?.data.filter((box: any) => checkBoxMultiple.value.indexOf(box.NRCRITERIOTAREFACHK) >= 0),
                DATERANGE: dataRange,
                DIASEMANA: diaSemana,
                VISTORIA: Metadata.getInstance<Select>('selectCriarVistoria').value,
                OBSERVACOES: Metadata.getInstance<Select>('selectObservacoesObrigatorias').value,
                EXECUTORHORA: dados,
                SWITCHFUNCIONARIO: false,
                NRSEQCONTRATO: Metadata.getInstance<SelectMultiple>('NRSEQCONTRATO').value,
            }).then(() => {
                Utilities.showSuccessMessage();
                this.fecharModalTarefas();
                grid.datasource.get();
            }).catch((error: any) => {
                Utilities.showErrorMessage(error);
            }).finally(() => {
                LoadingService.hide();
            });
        } else {
            DialogService.show({
                name: 'error_dialog',
                type: 'error',
                title: 'Erro',
                text: "O período selecionado não possui o(s) dia(s) da semana escolhido.",
            });
        }

    }
    /* ============================================================================================ */

    public excluirTarefas({ event }: any) {
        Utilities.showConfirmDeleteMessage(event, 'Fm00004000TarefasController.aposConfirmarDelete', 'Excluir Registro?');
    }

    public aposConfirmarDelete() {
        const component = Metadata.getInstance<TekGrid>('tek-grid-tarefas');
        LoadingService.show();
        Http.post('/inativarTarefas', {
            NRS: component.selectedRows.map((element: any) => element.NRCHECKLISTAGEND),
        }).then(() => {
            component.datasource.get();
            Utilities.showSuccessMessage();
        }).catch((error: any) => {
            Utilities.showErrorMessage(error);
        }).finally(() => {
            component.selectedRows = [];
            LoadingService.hide();
            DialogService.hide();
        });
    }

    //Controle do campo de adicionar e deletar novas linhas 
    public async novoHorario() {
        const form = Metadata.getInstance<Form>('formTarefas_dropBoxDadosAgendamento');
        const switchValue = Metadata.getInstance<Switch>('switchFunionario');
        let numAleatorio: any;

        // while responsável por atribuir aletaróriamente um número no fim dos "names" para nao gerar conflito.
        while (true) {
            numAleatorio = Math.floor(Math.random() * 100);
            if (form.children.filter((element: any) => element.name == "selectHoraInicio" + String(numAleatorio))) {
                break;
            }
        }

        if (form.children.length > 6) {
            const formulario: any = form?.children[form.children.length - 2];
            formulario.children[0].style.visibility = "hidden";
        }
        const renderizar = this.criaNovoHorario(numAleatorio);
        form.children = form.children.slice(0, form.children.length - 1).concat(renderizar, form.children[form.children.length - 1]);

        if (switchValue.value) {
            this.acessorVisivel = false;
        } else {
            this.acessorVisivel = true;
        }
        switchValue.disabled = true;
    }

    public removeHorario() {
        const form = Metadata.getInstance<Form>('formTarefas_dropBoxDadosAgendamento');
        const switchValue = Metadata.getInstance<Switch>('switchFunionario');
        form.children.splice(form.children.length - 2, 1);

        if (form.children.length > 6) {
            const formulario: any = form?.children[form.children.length - 2];
            formulario.children[0].style.visibility = "visible";
        } else {
            switchValue.disabled = false;
        }
    }

    // Molde para inserção de novos componentes ao modal de cadastro
    public criaNovoHorario(n: number): any {
        return [
            {
                name: "linhaColuna" + String(n),
                component: "ZdRow",
                justify: "space-between",
                grid: {
                    cols: 12
                },
                children: [
                    {
                        name: "botaoLixeira" + String(n),
                        component: "ZdButton",
                        icon: true,
                        small: true,
                        iconName: "mdi-trash-can-outline",
                        disabled: false,
                        cssClass: "zd-mt-4",
                        events: {
                            click: "{{Fm00004000TarefasController.removeHorario}}"
                        },
                        style: {
                            margin: "0 3% 1% 3%"
                        }
                    },
                    {
                        name: "selectHoraInicio" + String(n),
                        component: "ZdTime",
                        autocomplete: false,
                        label: "Horário Inicial",
                        timeFormat: "24hr",
                        placeholder: "00:00",
                        cssClass: "zd-mt-2",
                        mask: "##:##",
                        validations: {
                            required: {}
                        },
                        style: {
                            width: "17%"
                        }
                    },
                    {
                        name: "colSelectdDuracao" + String(n),
                        component: "ZdCol",
                        cols: 3,
                        children: [
                            {
                                name: "selectdDuracao" + String(n),
                                component: "ZdTextInput",
                                label: "Duração (minutos)",
                                placeholder: "00:00",
                                mask: "##:M#",
                                validations: {
                                    required: {},
                                    minLength: {
                                        limit: 4
                                    }
                                }
                            }
                        ]
                    },
                    {
                        name: "colSelectFuncionario" + String(n),
                        component: "ZdCol",
                        cols: 3,
                        children: [
                            {
                                name: "selectFuncionario" + String(n),
                                component: "ZdSelect",
                                autocomplete: false,
                                label: "Operador",
                                dataText: "NMOPERADOR",
                                dataValue: "CDOPERADOR",
                                isVisible: "{{Fm00004000TarefasController.acessorVisivel}}",
                                datasource: {
                                    route: "/getFuncionario",
                                    lazyLoad: true,
                                    type: "rest",
                                    loadAll: true
                                }
                            }
                        ]
                    },
                    {
                        name: "colSelectEncarregado" + String(n),
                        component: "ZdCol",
                        cols: 3,
                        children: [
                            {
                                name: "selectEncarregado" + String(n),
                                component: "ZdSelect",
                                autocomplete: false,
                                label: "Encarregado",
                                dataText: "NMOPERADOR",
                                columns: "3",
                                isVisible: "{{Fm00004000TarefasController.acessorVisivel}}",
                                dataValue: "CDOPERADOR",
                                datasource: {
                                    route: "/getSupervisorTarefa",
                                    lazyLoad: true,
                                    type: "rest",
                                    loadAll: true
                                }
                            }
                        ]
                    }
                ]
            }
        ];
    }

    // FUNÇÕES PARA CONTROLE DE CONFLITOS 

    // Recebe um intervalo de data/hora para ser comaprado com o grid afim de validar se há valores iguais.
    // dig == data inicial grid. dfg == data final grid
    // din == data inicial nova. dfn == data final nova
    public validaHorario(din: any, dfn: any, funcionario: any, encarregado: any, index: any, HORAINICIO: any) {
        const grid = Metadata.getInstance<TekGrid>('tek-grid-tarefas').datasource.data;
        grid.forEach(element => {
            const dig = Utilities.creatDate(element.DTHORAAGEND);
            const dfg = Utilities.creatDate(element.DTHRFINALAGEND);
            if (funcionario === element.CDOPERADOR) {
                if ((din.valueOf() >= dig.valueOf() && din.valueOf() <= dfg.valueOf()
                    || dfn.valueOf() >= dig.valueOf() && dfn.valueOf() <= dfg.valueOf()) ||
                    dig.valueOf() >= din.valueOf() && dig.valueOf() <= dfn.valueOf()
                    || dig.valueOf() >= din.valueOf() && dig.valueOf() <= dfn.valueOf()) {
                    const teste = this.conflitoDatas.findIndex((elemento: any) => elemento.INDEX == index);
                    if (teste < 0) {
                        this.conflitoDatas.push({
                            INDEX: index,
                            DHINICIALNOVA: din.toLocaleDateString('pt-br') + " " + ("00" + din.getHours()).slice(-2) + ':' + ("00" + din.getMinutes()).slice(-2),
                            DHFINALNOVA: dfn.toLocaleDateString('pt-br') + " " + ("00" + dfn.getHours()).slice(-2) + ':' + ("00" + dfn.getMinutes()).slice(-2),
                            INDEXPAI: null,
                            NMOPERADOR: element.NMOPERADOR,
                            CDOPERADOR: element.CDOPERADOR,
                            ENCARREGADO: encarregado,
                            HORAINICIO: HORAINICIO,
                            acoesSelect: 'Não',
                        });
                    }
                    this.conflitoDatas.push({
                        DHINICIALGRID: dig.toLocaleDateString('pt-br') + " " + ("00" + dig.getHours()).slice(-2) + ':' + ("00" + dig.getMinutes()).slice(-2),
                        DHFINALGRID: dfg.toLocaleDateString('pt-br') + " " + ("00" + dfg.getHours()).slice(-2) + ':' + ("00" + dfg.getMinutes()).slice(-2),
                        INDEX: `${index}${this.conflitoDatas.length}`,
                        INDEXPAI: index,
                        NRCHECKLISTAGEND: element.NRCHECKLISTAGEND,
                        NMCHECKLISTAGEND: element.NMCHECKLISTAGEND,
                    });
                }
            }
        });
    }

    public validaParametrizacao() {
        Http.get('getParametroConflito').then((response) => {
            this.parametrizacao = response.data[0]['IDVALIDACRIATAREFA'];
        });
    }

    // Pega as informações do form como data inicial, duração e funcionário. Formata para ser compatível com a data do Grid vinda do backEnd.
    public formatarDataHora(editedRow: any, revalidar: boolean) {
        if (this.validaInsercao()) {
            let index = 1;
            const dataRange = Metadata.getInstance<DateRange>('selectDataDe').value;
            const dataFormatada = this.formataData(dataRange);
            const diasSemana = Metadata.getInstance<SelectMultiple>('selectDiaSemana').value;
            if (revalidar == true) {
                const grid = Metadata.getInstance<TekTreeGrid>('tek-grid-nova-tarefa');
                const HORAINICIO = 0;
                editedRow.forEach((iteracoes: any) => {
                    let din = Utilities.creatDate(iteracoes.DHINICIALNOVA);
                    let dfn = Utilities.creatDate(iteracoes.DHFINALNOVA);
                    let CDOPERADOR = (iteracoes.NMOPERADOR.length == 12) ? iteracoes.NMOPERADOR : iteracoes.CDOPERADOR;
                    let duracao = ((dfn.valueOf() - din.valueOf()) / 1000 / 60);
                    const [hora, minuto] = iteracoes.HORAINICIO.split(':');
                    din.setHours(hora);
                    din.setMinutes(minuto);
                    dfn = new Date(din.valueOf());
                    dfn.setMinutes(dfn.getMinutes() + duracao);
                    this.validaHorario(din, dfn, CDOPERADOR, iteracoes.encarregado, iteracoes.INDEX, HORAINICIO);
                     this.fecharModalConflitoDatas();
                    //this.montaGrid();
                });
            } else {

                this.conflitoDatas = [];
                this.bancoConflito = [];
                this.executorHora().forEach(element => {
                    let dataInicio = new Date(dataFormatada[0].valueOf());
                    for (dataInicio; dataInicio <= dataFormatada[1]; dataInicio.setDate(dataInicio.getDate() + 1)) {
                        if (diasSemana.includes(String(dataInicio.getDay()))) {
                            const din = new Date(dataInicio.valueOf());
                            const [hora, minuto] = element.HORAINICIO.split(':');
                            let HORAINICIO = element.HORAINICIO;
                            din.setHours(hora);
                            din.setMinutes(minuto);
                            const dfn = new Date(din.valueOf());
                            dfn.setMinutes(dfn.getMinutes() + (Math.trunc(element.DURACAO / 100) * 60) + (element.DURACAO % 100));
                            this.copy = JSON.parse(JSON.stringify(element));
                            this.copy['INDEX'] = index;
                            this.copy['DURACAO'] = ((dfn.valueOf() - din.valueOf()) / 1000 / 60)
                            this.copy['DATAFINAL'] = dfn.toLocaleDateString('pt-br') + " " + ("00" + dfn.getHours()).slice(-2) + ':' + ("00" + dfn.getMinutes()).slice(-2);
                            this.copy["DATAINICIAL"] = din.toLocaleDateString('pt-br') + " " + ("00" + din.getHours()).slice(-2) + ':' + ("00" + din.getMinutes()).slice(-2);
                            this.bancoConflito.push(this.copy);
                            (this.parametrizacao == "N") ? this.validaHorario(din, dfn, element.FUNCIONARIO, element.ENCARREGADO, index, HORAINICIO) : "";
                            index++;
                        }
                    }
                });

            }

            this.title = Metadata.getInstance<TextInput>('nomeTarefa').value;
            revalidar = false;
            if (this.conflitoDatas.length > 0) {
                this.exibirModalConflitoDatas();
            } else {
                this.fecharModalTarefas();
                this.inserirTarefa();
            }
        }
    }

    public confirmaInsersao() {
        if (this.conflitoDatas.length > 0) {
            Utilities.alertMessage('Existem conflitos pendentes!', 'error');
        } else {
            this.fecharModalConflitoDatas();
            this.fecharModalTarefas();
            this.inserirTarefa();
        }
    }

    // Pega o dataRange da função formatarDataHora e converete para formato Date, retornando na linha 223.
    public formataData(dataRange: any) {
        const [mesInicial, diaInicial, anoInicial] = dataRange[0].split('/');
        const [mesFinal, diaFinal, anoFinal] = dataRange[1].split('/');
        return [new Date(anoInicial, mesInicial - 1, diaInicial), new Date(anoFinal, mesFinal - 1, diaFinal)]
    }

    public montaGrid() {
        const grid = Metadata.getInstance<TekTreeGrid>('tek-grid-nova-tarefa');
        const dadosPai = this.conflitoDatas.filter((dados: any) => (dados.INDEXPAI == null))
        dadosPai.forEach((dados: any) => {
            grid.datasource.data.push({
                DHINICIALNOVA: dados.DHINICIALNOVA,
                DHFINALNOVA: dados.DHFINALNOVA,
                NMOPERADOR: dados.NMOPERADOR,
                INDEX: dados.INDEX,
                INDEXPAI: dados.INDEXPAI,
                NRCHECKLISTAGEND: dados.NRCHECKLISTAGEND,
                CDOPERADOR: dados.CDOPERADOR,
                HORAINICIO: dados.HORAINICIO,
                acoesSelect: dados.acoesSelect,
            });
        });
    }

    public montaGridConflito({ row }: any) {
        const grid = Metadata.getInstance<TekGrid>('tek-grid-conflito-datas');
        grid.datasource.data = [];
        const dadosFilho = this.conflitoDatas.filter((dados: any) => (dados.INDEXPAI == row.INDEX))
        dadosFilho.forEach((dados: any) => {
            grid.datasource.data.push({
                DHINICIALGRID: dados.DHINICIALGRID,
                DHFINALGRID: dados.DHFINALGRID,
                NRCHECKLISTAGEND: dados.NRCHECKLISTAGEND,
                NMCHECKLISTAGEND: dados.NMCHECKLISTAGEND,
                INDEX: dados.INDEX,
                INDEXPAI: dados.INDEXPAI
            });
        });
        this.rowClickFiltroGrid();
    }

    // public trocaOpcoes({ component, row }: any) {
    //     if (component.value === "2") {
    //        return true;
    //     } 
    // }

    public rowClickFiltroGrid() {
        this.visibilidadeGridItens = true;
        this.visibilidadeForm = !this.visibilidadeGridItens;
    }

    public verificarConflitos({ component }: IEventParam<TekGrid>) {
        if (Utilities.validateGrid(component)) {
            this.atualizaBancoConflitos(component.getEditedRows());
            const alteracoes: any = component.getEditedRows().filter((elemento: any) => elemento.acoesSelect != 1);
            const revalidar = true;
            this.conflitoDatas = [];
            this.formatarDataHora(alteracoes, revalidar);
        }
    }

    public atualizaBancoConflitos(dadosEditados: any) {
        dadosEditados.forEach((element: any) => {
            const dataInicio = Utilities.creatDate(element['DHINICIALNOVA']);
            const din = new Date(dataInicio.valueOf());
            const [hora, minuto] = element.HORAINICIO.split(':');
            din.setHours(hora);
            din.setMinutes(minuto);
            const pos = this.bancoConflito.findIndex((dados: any) => dados.INDEX == element.INDEX);
            this.bancoConflito[pos]["FUNCIONARIO"] = (element.NMOPERADOR.length == 12) ? element.NMOPERADOR : element.CDOPERADOR;
            this.bancoConflito[pos]["DATAINICIAL"] = din.toLocaleDateString('pt-br') + " " + ("00" + din.getHours()).slice(-2) + ':' + ("00" + din.getMinutes()).slice(-2);
            this.bancoConflito[pos]["IGNORAR"] = element.acoesSelect;
            this.bancoConflito[pos]['DATAFINAL'] = din.toLocaleDateString('pt-br') + " " + ("00" + din.getHours()).slice(-2) + ':' + ("0000" + String(this.bancoConflito[pos]['DURACAO'])).slice(-2);
        });
    }
}


